"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterListQueryMiddleware = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const error_1 = require("./error");
const workflow_schema_1 = require("./workflow.schema");
function toQueryFilter(rawFilter, schema) {
    const parsedFilter = new schema((0, n8n_workflow_1.jsonParse)(rawFilter, { errorMessage: 'Failed to parse filter JSON' }));
    return Object.fromEntries(Object.entries(parsedFilter)
        .filter(([_, value]) => value !== undefined)
        .map(([key, _]) => [key, parsedFilter[key]]));
}
const filterListQueryMiddleware = (req, res, next) => {
    const { filter: rawFilter } = req.query;
    if (!rawFilter)
        return next();
    let schema;
    if (req.baseUrl.endsWith('workflows')) {
        schema = workflow_schema_1.WorkflowSchema;
    }
    else {
        return next();
    }
    try {
        const filter = toQueryFilter(rawFilter, schema);
        if (Object.keys(filter).length === 0)
            return next();
        req.listQueryOptions = { ...req.listQueryOptions, filter };
        next();
    }
    catch (error) {
        (0, error_1.handleListQueryError)('filter', rawFilter, error);
    }
};
exports.filterListQueryMiddleware = filterListQueryMiddleware;
//# sourceMappingURL=filter.js.map